summaryrefslogtreecommitdiff
path: root/win32
diff options
context:
space:
mode:
authorSteve Hay <SteveHay@planit.com>2007-10-08 10:17:41 +0000
committerSteve Hay <SteveHay@planit.com>2007-10-08 10:17:41 +0000
commit9788a75a4d0043e8bce3f9aa0964e76e23ee2c3c (patch)
tree3117a57ff901dace0b4946963560090bc2784247 /win32
parent7d3b1f61da54c4cf5210c73ac1c807d0eea47175 (diff)
downloadperl-9788a75a4d0043e8bce3f9aa0964e76e23ee2c3c.tar.gz
Do the same as #32061 for Win32, which also fixes a static linking
build problem with Hash/Util/FieldHash p4raw-id: //depot/perl@32066
Diffstat (limited to 'win32')
-rw-r--r--win32/FindExt.pm11
-rw-r--r--win32/Makefile3
-rw-r--r--win32/makefile.mk3
3 files changed, 10 insertions, 7 deletions
diff --git a/win32/Makefile b/win32/Makefile
index cc572c32e4..f07a62bc47 100644
--- a/win32/Makefile
+++ b/win32/Makefile
@@ -798,8 +798,7 @@ SETARGV_OBJ = setargv$(o)
# - Win32 extension contains overlapped symbols with win32.c (BUG!)
# - MakeMaker isn't capable enough for SDBM_File (smaller bug)
# - Encode (encoding search algorithm relies on shared library?)
-# - Hash/Util (fails various tests when linked statically)
-STATIC_EXT = * !Win32 !SDBM_File !Encode !Hash/Util
+STATIC_EXT = * !Win32 !SDBM_File !Encode
!ELSE
# specify static extensions here, for example:
#STATIC_EXT = Cwd Compress/Raw/Zlib
diff --git a/win32/makefile.mk b/win32/makefile.mk
index d4e67c40de..2f99285a17 100644
--- a/win32/makefile.mk
+++ b/win32/makefile.mk
@@ -954,8 +954,7 @@ SETARGV_OBJ = setargv$(o)
# - Win32 extension contains overlapped symbols with win32.c (BUG!)
# - MakeMaker isn't capable enough for SDBM_File (smaller bug)
# - Encode (encoding search algorithm relies on shared library?)
-# - Hash/Util (fails various tests when linked statically)
-STATIC_EXT = * !Win32 !SDBM_File !Encode !Hash/Util
+STATIC_EXT = * !Win32 !SDBM_File !Encode
.ELSE
# specify static extensions here, for example:
#STATIC_EXT = Cwd Compress/Raw/Zlib
diff --git a/win32/FindExt.pm b/win32/FindExt.pm
index b2386b1501..4038017b51 100644
--- a/win32/FindExt.pm
+++ b/win32/FindExt.pm
@@ -103,13 +103,18 @@ sub find_ext
}
}
# Special case: Add in threads/shared since it is not picked up by the
# recursive find above (and adding in general recursive finding breaks
# SDBM_File/sdbm). A.D. 10/25/2001.
if (!$_[0] && -d "threads/shared") {
$ext{"threads/shared"} = 'dynamic';
}
+ if (!$_[0] && -d "Hash/Util/FieldHash") {
+ $ext{"Hash/Util/FieldHash"} = 'dynamic';
+ }
}
1;
@@ -103,13 +103,18 @@ sub find_ext
}
}
-# Special case: Add in threads/shared since it is not picked up by the
-# recursive find above (and adding in general recursive finding breaks
-# SDBM_File/sdbm). A.D. 10/25/2001.
+# Special case: Add in modules that nest beyond the first level.
+# Currently threads/shared and Hash/Util/FieldHash, since they are
+# not picked up by the recursive find above (and adding in general
+# recursive finding breaks SDBM_File/sdbm).
+# A.D. 20011025 (SDBM), ajgough 20071008 (FieldHash)
if (!$_[0] && -d "threads/shared") {
$ext{"threads/shared"} = 'dynamic';